---
title: logging
sidebarTitle: logging
---

# `fastmcp.client.logging`

## Functions

### `create_log_callback` <sup><a href="https://github.com/jlowin/fastmcp/blob/main/src/fastmcp/client/logging.py#L20"><Icon icon="github" size="14" /></a></sup>

```python
create_log_callback(handler: LogHandler | None = None) -> LoggingFnT
```
